pub struct WindowsOsInfo {
pub kernel_info: Option<KernelInfo>,
pub processes: HashMap<i32, Process>,
pub modules: HashMap<i32, Vec<Module>>,
pub symbol_lookup_trees: HashMap<i32, IntervalTree<u64, SymbolInfo>>,
pub not_found_full_name_cache: HashSet<String>,
pub instruction_callbacks: HashMap<i32, CpuInstrumentationCbHandle>,
}Expand description
Container for various types of information about a running Windows OS
Fields
kernel_info: Option<KernelInfo>Kernel info
processes: HashMap<i32, Process>Per-CPU current process, there may be overlap between them.
modules: HashMap<i32, Vec<Module>>Per-CPU kernel module list, there may be overlap between them.
symbol_lookup_trees: HashMap<i32, IntervalTree<u64, SymbolInfo>>Per-CPU Symbol lookup trees
not_found_full_name_cache: HashSet<String>Cache of full names of both processes and kernel modules which are not found from the pdb server
instruction_callbacks: HashMap<i32, CpuInstrumentationCbHandle>Callbacks on instruction to do coverage lookups
Implementations
Sourceimpl WindowsOsInfo
impl WindowsOsInfo
Sourcepub fn collect<P>(
&mut self,
processor: *mut ConfObject,
download_directory: P,
user_debug_info: &mut DebugInfoConfig<'_>,
source_cache: &SourceCache,
) -> Result<()>
pub fn collect<P>( &mut self, processor: *mut ConfObject, download_directory: P, user_debug_info: &mut DebugInfoConfig<'_>, source_cache: &SourceCache, ) -> Result<()>
Collect or refresh OS info. Typically run on new CR3 writes to refresh for possibly-changed address space mappings.